EasyPrint class

This handles the operations that the package can do with StackTraces.

Constructors

EasyPrint([PrintingFunction? printingFn])
This handles the operations that the package can do with StackTraces.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
printingFn PrintingFunction
Defines which function will be used to print (default is stdout.writeln)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUp<R>(FutureOrReturningFn<R> body) → void
The required SetUp for the EasyPrint package to work. Define it in your bootstrap.
toString() String
A string representation of this object.
inherited
wrapInPrintZone<R>(FutureOrReturningFn<R> body, PrintZone zone) FutureOr<R?>
A function that wraps the code that is ran beneath body in it's own PrintZone.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EasyPrint?
singleton for EasyPrint
getter/setter pair