FutureOrReturningFn<R> typedef
FutureOrReturningFn<R> =
FutureOr<R> Function()
A function with the code to be executed in a zone.
Implementation
typedef FutureOrReturningFn<R> = FutureOr<R> Function();
A function with the code to be executed in a zone.
typedef FutureOrReturningFn<R> = FutureOr<R> Function();