PrintingFunction typedef

PrintingFunction = void Function(String line)

A PrintingFunction is a function that receives a scoped formatted String with the intention of delegating the printing of it to the user as he wants.

Implementation

typedef PrintingFunction = void Function(
  String line,
);