PrintZone class
A PrintZone is a specification on how to handle print calls. It's intended to define a custom print behavior.
- Annotations
-
- @immutable
Constructors
- PrintZone({required String zoneName, String badge = '🚀', CallMetadataParser? location, CallMetadataParser? functionName, AnsiCreator? penColor, LogLevel logLevel = LogLevel.debug})
- The constructor for a PrintZone.
Properties
- badge → String
-
The badge of the zone (printed on the englobing box). It's intended to be
an emoji. Defaults to '🚀'.
final
- functionName ↔ CallMetadataParser
-
The function name of the caller.
latefinal
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String
-
Override this for changing the label of the zone (printed on the englobing
box)
no setter
- location ↔ CallMetadataParser
-
The file location the zone is being called from.
latefinal
- logLevel → LogLevel
-
Define a LogLevel for the logs of this zone.
final
- penColor ↔ AnsiCreator
-
Define a color for displaying the logs of this zone in a console
environment.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zoneName → String
-
The name of the zone from which the print call is being made.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override